==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_backup_gateway/paginator.py <==
"""
Type annotations for backup-gateway service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_backup_gateway.client import BackupGatewayClient
    from types_boto3_backup_gateway.paginator import (
        ListGatewaysPaginator,
        ListHypervisorsPaginator,
        ListVirtualMachinesPaginator,
    )

    session = Session()
    client: BackupGatewayClient = session.client("backup-gateway")

    list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
    list_hypervisors_paginator: ListHypervisorsPaginator = client.get_paginator("list_hypervisors")
    list_virtual_machines_paginator: ListVirtualMachinesPaginator = client.get_paginator("list_virtual_machines")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListGatewaysInputListGatewaysPaginateTypeDef,
    ListGatewaysOutputTypeDef,
    ListHypervisorsInputListHypervisorsPaginateTypeDef,
    ListHypervisorsOutputTypeDef,
    ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef,
    ListVirtualMachinesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListGatewaysPaginator", "ListHypervisorsPaginator", "ListVirtualMachinesPaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListGatewaysPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListGateways.html#BackupGateway.Paginator.ListGateways)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listgatewayspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGatewaysInputListGatewaysPaginateTypeDef]
    ) -> _PageIterator[ListGatewaysOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListGateways.html#BackupGateway.Paginator.ListGateways.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listgatewayspaginator)
        """


class ListHypervisorsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListHypervisors.html#BackupGateway.Paginator.ListHypervisors)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listhypervisorspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListHypervisorsInputListHypervisorsPaginateTypeDef]
    ) -> _PageIterator[ListHypervisorsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListHypervisors.html#BackupGateway.Paginator.ListHypervisors.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listhypervisorspaginator)
        """


class ListVirtualMachinesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListVirtualMachines.html#BackupGateway.Paginator.ListVirtualMachines)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listvirtualmachinespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef]
    ) -> _PageIterator[ListVirtualMachinesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListVirtualMachines.html#BackupGateway.Paginator.ListVirtualMachines.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listvirtualmachinespaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_backup_gateway/paginator.py <==
"""
Type annotations for backup-gateway service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_backup_gateway.client import BackupGatewayClient
    from types_boto3_backup_gateway.paginator import (
        ListGatewaysPaginator,
        ListHypervisorsPaginator,
        ListVirtualMachinesPaginator,
    )

    session = Session()
    client: BackupGatewayClient = session.client("backup-gateway")

    list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
    list_hypervisors_paginator: ListHypervisorsPaginator = client.get_paginator("list_hypervisors")
    list_virtual_machines_paginator: ListVirtualMachinesPaginator = client.get_paginator("list_virtual_machines")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListGatewaysInputPaginateTypeDef,
    ListGatewaysOutputTypeDef,
    ListHypervisorsInputPaginateTypeDef,
    ListHypervisorsOutputTypeDef,
    ListVirtualMachinesInputPaginateTypeDef,
    ListVirtualMachinesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListGatewaysPaginator", "ListHypervisorsPaginator", "ListVirtualMachinesPaginator")


if TYPE_CHECKING:
    _ListGatewaysPaginatorBase = Paginator[ListGatewaysOutputTypeDef]
else:
    _ListGatewaysPaginatorBase = Paginator  # type: ignore[assignment]


class ListGatewaysPaginator(_ListGatewaysPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListGateways.html#BackupGateway.Paginator.ListGateways)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listgatewayspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListGatewaysInputPaginateTypeDef]
    ) -> PageIterator[ListGatewaysOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListGateways.html#BackupGateway.Paginator.ListGateways.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listgatewayspaginator)
        """


if TYPE_CHECKING:
    _ListHypervisorsPaginatorBase = Paginator[ListHypervisorsOutputTypeDef]
else:
    _ListHypervisorsPaginatorBase = Paginator  # type: ignore[assignment]


class ListHypervisorsPaginator(_ListHypervisorsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListHypervisors.html#BackupGateway.Paginator.ListHypervisors)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listhypervisorspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListHypervisorsInputPaginateTypeDef]
    ) -> PageIterator[ListHypervisorsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListHypervisors.html#BackupGateway.Paginator.ListHypervisors.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listhypervisorspaginator)
        """


if TYPE_CHECKING:
    _ListVirtualMachinesPaginatorBase = Paginator[ListVirtualMachinesOutputTypeDef]
else:
    _ListVirtualMachinesPaginatorBase = Paginator  # type: ignore[assignment]


class ListVirtualMachinesPaginator(_ListVirtualMachinesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListVirtualMachines.html#BackupGateway.Paginator.ListVirtualMachines)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listvirtualmachinespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListVirtualMachinesInputPaginateTypeDef]
    ) -> PageIterator[ListVirtualMachinesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway/paginator/ListVirtualMachines.html#BackupGateway.Paginator.ListVirtualMachines.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_backup_gateway/paginators/#listvirtualmachinespaginator)
        """
